==> sptk-3.5.7.05.tbz2: sptk-3.5.7.05/sptk3/sptk.h <==
/***************************************************************************
                          SIMPLY POWERFUL TOOLKIT (SPTK)
                          sptk.h  -  description
                             -------------------
    begin                : Mon Apr 17 2000
    copyright            : (C) 2000-2007 by Alexey Parshin. All rights reserved.
    email                : alexeyp@gmail.com
 ***************************************************************************/

/***************************************************************************
  Redistribution and use in source and binary forms, with or without 
  modification, are permitted provided that the following conditions are met:

  * Redistributions of source code must retain the above copyright notice, 
    this list of conditions and the following disclaimer.
  * Redistributions in binary form must reproduce the above copyright notice, 
    this list of conditions and the following disclaimer in the documentation 
    and/or other materials provided with the distribution.
  * Neither the name of the <ORGANIZATION> nor the names of its contributors 
    may be used to endorse or promote products derived from this software 
    without specific prior written permission.

  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER 
  OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
  EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
  PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
  PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
  LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
  NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
  SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 ***************************************************************************/

#ifndef __SPTK_H_
#define __SPTK_H__

#if defined(__GNUC__) || defined(__SUNPRO_CC)
    #define __UNIX_COMPILER__
#endif

#ifndef __UNIX_COMPILER__
#  if defined(SP_DLL) && defined(WIN32)
#    ifdef SP_LIBRARY
#      define SP_EXPORT   __declspec(dllexport)
#    else
#      define SP_EXPORT   __declspec(dllimport)
#    endif
#  else
#    define SP_EXPORT
#  endif
#else
#  define SP_EXPORT
#endif

#if defined(_MSC_VER)
    #include <sptk3/sptk-config.h.win>
    #include <winsock2.h>
    #include <windows.h>
    #pragma warning (disable: 4290)
    #pragma warning (disable: 4355)
    #pragma warning (disable: 4786)
    #pragma warning (disable: 4996)
#else
    #include <sptk3/sptk-config.h>
#endif

#include <map>
#include <string>
#include <vector>

namespace sptk {
#define ALIGN_LEFT   1
#define ALIGN_RIGHT  2
#define ALIGN_CENTER 3

/// Workaround for VC++ bug
typedef std::string std_string;
}

#ifdef __UNIX_COMPILER__
    #include <stdint.h>
    #include <inttypes.h>
#else
    #define int16_t  __int16
    #define uint16_t unsigned __int16
    #define int32_t  __int32
    #define uint32_t unsigned __int32
    #define int64_t  __int64
    #define uint64_t unsigned __int64
#endif

#endif

==> sptk-3.5.7.14.tbz2: sptk-3.5.7.14/sptk3/sptk.h <==
/***************************************************************************
                          SIMPLY POWERFUL TOOLKIT (SPTK)
                          sptk.h  -  description
                             -------------------
    begin                : Mon Apr 17 2000
    copyright            : (C) 2000-2008 by Alexey Parshin. All rights reserved.
    email                : alexeyp@gmail.com
 ***************************************************************************/

/***************************************************************************
  Redistribution and use in source and binary forms, with or without 
  modification, are permitted provided that the following conditions are met:

  * Redistributions of source code must retain the above copyright notice, 
    this list of conditions and the following disclaimer.
  * Redistributions in binary form must reproduce the above copyright notice, 
    this list of conditions and the following disclaimer in the documentation 
    and/or other materials provided with the distribution.
  * Neither the name of the <ORGANIZATION> nor the names of its contributors 
    may be used to endorse or promote products derived from this software 
    without specific prior written permission.

  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER 
  OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
  EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
  PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
  PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
  LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
  NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
  SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 ***************************************************************************/

#ifndef __SPTK_H_
#define __SPTK_H__

#if defined(__GNUC__) || defined(__SUNPRO_CC)
    #define __UNIX_COMPILER__
#endif

#ifndef __UNIX_COMPILER__
#  if defined(SP_DLL) && defined(WIN32)
#    ifdef SP_LIBRARY
#      define SP_EXPORT   __declspec(dllexport)
#    else
#      define SP_EXPORT   __declspec(dllimport)
#    endif
#  else
#    define SP_EXPORT
#  endif
#else
#  define SP_EXPORT
#endif

#if defined(_MSC_VER) || defined(__BORLANDC__)
    #include <sptk3/sptk-config.h.win>
    #include <winsock2.h>
    #include <windows.h>
    #pragma warning (disable: 4290)
    #pragma warning (disable: 4355)
    #pragma warning (disable: 4786)
    #pragma warning (disable: 4996)
#else
    #include <sptk3/sptk-config.h>
#endif

#include <map>
#include <string>
#include <vector>

namespace sptk {
#define ALIGN_LEFT   1
#define ALIGN_RIGHT  2
#define ALIGN_CENTER 3

/// Workaround for VC++ bug
typedef std::string std_string;
}

#ifdef __UNIX_COMPILER__
	#include <stdint.h>
	#include <inttypes.h>
#else
	#ifdef __BORLANDC__
		#include <stdint.h>
		#include <ctype.h>
	#else
		#define int16_t  __int16
		#define uint16_t unsigned __int16
		#define int32_t  __int32
		#define uint32_t unsigned __int32
		#define int64_t  __int64
		#define uint64_t unsigned __int64
	#endif
#endif

#endif
